@@ -1,3 +1,19 @@
+# Copyright (C) 2021-2022 Hibiki AI Limited <info@hibiki-ai.com>
+#
+# This file is part of ichimoku.
+#
+# ichimoku is free software: you can redistribute it and/or modify it under the
+# terms of the GNU General Public License as published by the Free Software
+# Foundation, either version 3 of the License, or (at your option) any later
+# version.
+#
+# ichimoku is distributed in the hope that it will be useful, but WITHOUT ANY
+# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
+# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License along with
+# ichimoku. If not, see <https://www.gnu.org/licenses/>.
+
 # Ichimoku - OANDA fxTrade API Interface ---------------------------------------
 
 #' OANDA Price Data
@@ -408,7 +424,7 @@ oanda_chart <- function(instrument,
                         refresh = 5,
                         count = 250,
                         price = c("M", "B", "A"),
-                        theme = c("original", "conceptual", "dark", "fresh", "mono", "solarized"),
+                        theme = c("classic", "dark", "mono", "noguchi", "okabe-ito", "solarized"),
                         type = c("none", "r", "s"),
                         limit,
                         server,
@@ -535,7 +551,7 @@ oanda_studio <- function(instrument = "USD_JPY",
                          refresh = 5,
                          count = 300,
                          price = c("M", "B", "A"),
-                         theme = c("original", "conceptual", "dark", "fresh", "mono", "solarized"),
+                         theme = c("classic", "dark", "mono", "noguchi", "okabe-ito", "solarized"),
                          type = c("none", "r", "s"),
                          server,
                          apikey,
@@ -601,7 +617,7 @@ oanda_studio <- function(instrument = "USD_JPY",
       shiny::fluidRow(
         shiny::column(width = 1,
                       shiny::selectInput("theme", label = "Theme",
-                                         choices = c("original", "conceptual", "dark", "fresh", "mono", "solarized"),
+                                         choices = c("classic", "dark", "mono", "noguchi", "okabe-ito", "solarized"),
                                          selected = theme, selectize = FALSE)),
         shiny::column(width = 1,
                       shiny::selectInput("type", label = "Indicator",
